.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth API reference.

Utility Package Reference
==========================

Contents:

.. toctree::
	:maxdepth: 2
	
	CmnCmdOpts
	DictTree
	DirWalk
	ExecTimer
	FileBuffer
	Histogram
	HtmlUtils
	XmlWrite
	
	plot/index_plot
